==> nextcloud-22.2.3.tgz: nextcloud/apps/dav/l10n/fi.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalenteri",
    "Todos" : "Tehtävät",
    "Personal" : "Henkilökohtainen",
    "{actor} created calendar {calendar}" : "{actor} loi kalenterin {calendar}",
    "You created calendar {calendar}" : "Loit kalenterin {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} poisti kalenterin {calendar}",
    "You deleted calendar {calendar}" : "Poistit kalenterin {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} päivitti kalenterin {calendar}",
    "You updated calendar {calendar}" : "Päivitit kalenterin {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} palautti kalenterin {calendar}",
    "You restored calendar {calendar}" : "Palautit kalenterin {calendar}",
    "You shared calendar {calendar} as public link" : "Jaoit kalenterin {calendar} julkisena linkkinä",
    "You removed public link for calendar {calendar}" : "Poistit julkisen linkin kalenterilta {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} jakoi kalenterin {calendar} kanssasi",
    "You shared calendar {calendar} with {user}" : "Jaoit kalenterin {calendar} käyttäjälle {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} jakoi kalenterin {calendar} käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} lopetti kalenterin {calendar} jakamisen kanssasi",
    "You unshared calendar {calendar} from {user}" : "Lopetit kalenterin {calendar} jakamisen käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} lopetti kalenterin {calendar} jakamisen käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} lopetti kalenterin {calendar} jakamisen itselleen",
    "You shared calendar {calendar} with group {group}" : "Jaoit kalenterin {calendar} ryhmälle {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} jakoi kalenterin {calendar} ryhmälle {group}",
    "You unshared calendar {calendar} from group {group}" : "Lopetit kalenterin {calendar} jakamisen ryhmälle {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} lopetti kalenterin {calendar} jakamisen ryhmälle {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} loi tapahtuman {event} kalenteriin {calendar}",
    "You created event {event} in calendar {calendar}" : "Loit tapahtuman {event} kalenteriin {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} poisti tapahtuman {event} kalenterista {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Poistit tapahtuman {event} kalenterista {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} päivitti tapahtuman {event} kalenteriin {calendar}",
    "You updated event {event} in calendar {calendar}" : "Päivitit tapahtuman {event} kalenteriin {calendar}",
    "Busy" : "Varattu",
    "{actor} created todo {todo} in list {calendar}" : "{actor} loi tehtävän {todo} listaan {calendar}",
    "You created todo {todo} in list {calendar}" : "Loit tehtävän {todo} listaan {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} poisti tehtävän {todo} listasta {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Poistit tehtävän {todo} listasta {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} päivitti tehtävän {todo} listassa {calendar}",
    "You updated todo {todo} in list {calendar}" : "Päivitit tehtävän {todo} listassa {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} suoritti tehtävän {todo} listasta {calendar}",
    "You solved todo {todo} in list {calendar}" : "Suoritit tehtävän {todo} listasta {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} avasi uudelleen tehtävän {todo} listassa {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Avasit uudelleen tehtävän {todo} listassa {calendar}",
    "Calendar, contacts and tasks" : "Kalenteri, yhteystiedot ja tehtävät",
    "A <strong>calendar</strong> was modified" : "<strong>Kalenteria</strong> on muokattu",
    "A calendar <strong>event</strong> was modified" : "Kalenterin <strong>tapahtumaa</strong> on muokattu",
    "A calendar <strong>todo</strong> was modified" : "Kalenterin <strong>tehtävää</strong> on muokattu",
    "Contact birthdays" : "Yhteystietojen syntymäpäivät",
    "Death of %s" : "%s kuolema",
    "Calendar:" : "Kalenteri:",
    "Date:" : "Päiväys:",
    "Where:" : "Missä:",
    "Description:" : "Kuvaus:",
    "Untitled event" : "Nimetön tapahtuma",
    "_%n year_::_%n years_" : ["%n vuosi","%n vuotta"],
    "_%n month_::_%n months_" : ["%n kuukausi","%n kuukautta"],
    "_%n day_::_%n days_" : ["%n päivä","%n päivää"],
    "_%n hour_::_%n hours_" : ["%n tunti","%n tuntia"],
    "_%n minute_::_%n minutes_" : ["%n minuutti","%n minuuttia"],
    "%s (%s ago)" : "%s (%s sitten)",
    "Calendar: %s" : "Kalenteri: %s",
    "Date: %s" : "Päiväys: %s",
    "Description: %s" : "Kuvaus: %s",
    "Where: %s" : "Missä: %s",
    "Cancelled: %1$s" : "Peruutettu: %1$s",
    "Invitation canceled" : "Kutsu peruttu",
    "Invitation updated" : "Kutsu päivitetty",
    "Invitation: %1$s" : "Kutsu: %1$s",
    "Invitation" : "Kutsu",
    "Title:" : "Otsikko:",
    "Time:" : "Aika:",
    "Location:" : "Sijainti:",
    "Link:" : "Linkki:",
    "Organizer:" : "Järjestäjä:",
    "Attendees:" : "Osallistujat:",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "More options …" : "Lisää valintoja…",
    "More options at %s" : "Lisää valintoja kohteessa %s",
    "Contacts" : "Yhteystiedot",
    "{actor} created address book {addressbook}" : "{actor} loi osoitekirjan {addressbook}",
    "You created address book {addressbook}" : "Loit osoitekirjan {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} poisti osoitekirjan {addressbook}",
    "You deleted address book {addressbook}" : "Sinä poistit osoitekirjan {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} päivitti osoitekirjaa {addressbook}",
    "You updated address book {addressbook}" : "Sinä päivitit osoitekirjaa {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} jakoi osoitekirjan {addressbook} kanssasi",
    "You shared address book {addressbook} with {user}" : "Jaoit osoitekirjan {addressbook} käyttäjän {user} kanssa",
    "{actor} shared address book {addressbook} with {user}" : "{actor} jakoi osoitekirjan {addressbook} käyttäjän {user} kanssa",
    "You shared address book {addressbook} with group {group}" : "Jaoit osoitekirjan {addressbook} ryhmän {group} kanssa",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} jakoi osoitekirjan {addressbook} ryhmän {group} kanssa",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} loi yhteystiedon {card} osoitekirjaan {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Loit yhteystiedon {card} osoitekirjaan {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} poisti yhteystiedon {card} osoitekirjasta {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Poistit yhteystiedon {card} osoitekirjasta {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} päivitti yhteystietoa {card} osoitekirjassa {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Päivitit yhteystiedon {card} osoitekirjassa {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>Yhteystietoa</strong> tai <strong>osoitekirjaa</strong> muokattiin",
    "System is in maintenance mode." : "Järjestelmä on huoltotilassa",
    "Upgrade needed" : "Päivitys tarvitaan",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s tulee asettaa käyttämään HTTPS-yhteyttä, jotta CalDAVia ja CardDAVia voi käyttää iOSilla tai macOS:llä.",
    "Configures a CalDAV account" : "Määrittää CalDAV-tilin",
    "Configures a CardDAV account" : "Määrittää CardDAV-tilin",
    "Events" : "Tapahtumat",
    "Tasks" : "Tehtävät",
    "Untitled task" : "Nimetön tehtävä",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV-päätepiste",
    "Availability" : "Saatavuus",
    "Time zone:" : "Aikavyöhyke:",
    "Delete slot" : "Poista aikarako",
    "No working hours set" : "Työskentelytunteja ei ole asetettu",
    "Add slot" : "Lisää aikarako",
    "Save" : "Tallenna",
    "Monday" : "Maanantai",
    "Tuesday" : "Tiistai",
    "Wednesday" : "Keskiviikko",
    "Thursday" : "Torstai",
    "Friday" : "Perjantai",
    "Saturday" : "Lauantai",
    "Sunday" : "Sunnuntai",
    "Calendar server" : "Kalenteripalvelin",
    "Send invitations to attendees" : "Lähetä kutsut osallistujille",
    "Automatically generate a birthday calendar" : "Luo syntymäpäiväkalenteri automaattisesti",
    "Birthday calendars will be generated by a background job." : "Syntymäpäiväkalenterit luodaan taustatyön toimesta.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Sen vuoksi ne eivät ole välittömästi saatavilla käyttöönoton jälkeen, vaan ne tulevat näkyviin pienellä viiveellä.",
    "Send notifications for events" : "Lähetä ilmoitukset tapahtumista",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Asenna myös {calendarappstoreopen}kalenterisovellus{linkclose}, tai {calendardocopen}yhdistä tietokoneesi ja mobiililaitteesi synkronointiyhteyteen ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Varmista että määrität {emailopen}sähköpostipalvelimen{linkclose} asetukset oikein.",
    "There was an error updating your attendance status." : "Osallistumisesi tilaa päivittäessä tapahtui virhe.",
    "Please contact the organizer directly." : "Ota yhteys suoraan järjestäjään.",
    "Are you accepting the invitation?" : "Hyväksytkö kutsun?",
    "Tentative" : "Alustava",
    "Number of guests" : "Vieraiden määrä",
    "Comment" : "Kommentti",
    "Your attendance was updated successfully." : "Osallistumisesi päivitettiin onnistuneesti.",
    "Calendar and tasks" : "Kalenteri ja tehtävät"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.9.tgz: nextcloud/apps/dav/l10n/fi.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalenteri",
    "Todos" : "Tehtävät",
    "Personal" : "Henkilökohtainen",
    "{actor} created calendar {calendar}" : "{actor} loi kalenterin {calendar}",
    "You created calendar {calendar}" : "Loit kalenterin {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} poisti kalenterin {calendar}",
    "You deleted calendar {calendar}" : "Poistit kalenterin {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} päivitti kalenterin {calendar}",
    "You updated calendar {calendar}" : "Päivitit kalenterin {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} palautti kalenterin {calendar}",
    "You restored calendar {calendar}" : "Palautit kalenterin {calendar}",
    "You shared calendar {calendar} as public link" : "Jaoit kalenterin {calendar} julkisena linkkinä",
    "You removed public link for calendar {calendar}" : "Poistit julkisen linkin kalenterilta {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} jakoi kalenterin {calendar} kanssasi",
    "You shared calendar {calendar} with {user}" : "Jaoit kalenterin {calendar} käyttäjälle {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} jakoi kalenterin {calendar} käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} lopetti kalenterin {calendar} jakamisen kanssasi",
    "You unshared calendar {calendar} from {user}" : "Lopetit kalenterin {calendar} jakamisen käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} lopetti kalenterin {calendar} jakamisen käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} lopetti kalenterin {calendar} jakamisen itselleen",
    "You shared calendar {calendar} with group {group}" : "Jaoit kalenterin {calendar} ryhmälle {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} jakoi kalenterin {calendar} ryhmälle {group}",
    "You unshared calendar {calendar} from group {group}" : "Lopetit kalenterin {calendar} jakamisen ryhmälle {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} lopetti kalenterin {calendar} jakamisen ryhmälle {group}",
    "Untitled event" : "Nimetön tapahtuma",
    "{actor} created event {event} in calendar {calendar}" : "{actor} loi tapahtuman {event} kalenteriin {calendar}",
    "You created event {event} in calendar {calendar}" : "Loit tapahtuman {event} kalenteriin {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} poisti tapahtuman {event} kalenterista {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Poistit tapahtuman {event} kalenterista {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} päivitti tapahtuman {event} kalenteriin {calendar}",
    "You updated event {event} in calendar {calendar}" : "Päivitit tapahtuman {event} kalenteriin {calendar}",
    "Busy" : "Varattu",
    "{actor} created todo {todo} in list {calendar}" : "{actor} loi tehtävän {todo} listaan {calendar}",
    "You created todo {todo} in list {calendar}" : "Loit tehtävän {todo} listaan {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} poisti tehtävän {todo} listasta {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Poistit tehtävän {todo} listasta {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} päivitti tehtävän {todo} listassa {calendar}",
    "You updated todo {todo} in list {calendar}" : "Päivitit tehtävän {todo} listassa {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} suoritti tehtävän {todo} listasta {calendar}",
    "You solved todo {todo} in list {calendar}" : "Suoritit tehtävän {todo} listasta {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} avasi uudelleen tehtävän {todo} listassa {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Avasit uudelleen tehtävän {todo} listassa {calendar}",
    "Calendar, contacts and tasks" : "Kalenteri, yhteystiedot ja tehtävät",
    "A <strong>calendar</strong> was modified" : "<strong>Kalenteria</strong> on muokattu",
    "A calendar <strong>event</strong> was modified" : "Kalenterin <strong>tapahtumaa</strong> on muokattu",
    "A calendar <strong>todo</strong> was modified" : "Kalenterin <strong>tehtävää</strong> on muokattu",
    "Contact birthdays" : "Yhteystietojen syntymäpäivät",
    "Death of %s" : "%s kuolema",
    "Calendar:" : "Kalenteri:",
    "Date:" : "Päiväys:",
    "Where:" : "Missä:",
    "Description:" : "Kuvaus:",
    "_%n year_::_%n years_" : ["%n vuosi","%n vuotta"],
    "_%n month_::_%n months_" : ["%n kuukausi","%n kuukautta"],
    "_%n day_::_%n days_" : ["%n päivä","%n päivää"],
    "_%n hour_::_%n hours_" : ["%n tunti","%n tuntia"],
    "_%n minute_::_%n minutes_" : ["%n minuutti","%n minuuttia"],
    "%s (%s ago)" : "%s (%s sitten)",
    "Calendar: %s" : "Kalenteri: %s",
    "Date: %s" : "Päiväys: %s",
    "Description: %s" : "Kuvaus: %s",
    "Where: %s" : "Missä: %s",
    "Cancelled: %1$s" : "Peruutettu: %1$s",
    "Invitation canceled" : "Kutsu peruttu",
    "Invitation updated" : "Kutsu päivitetty",
    "Invitation: %1$s" : "Kutsu: %1$s",
    "Invitation" : "Kutsu",
    "Title:" : "Otsikko:",
    "Time:" : "Aika:",
    "Location:" : "Sijainti:",
    "Link:" : "Linkki:",
    "Organizer:" : "Järjestäjä:",
    "Attendees:" : "Osallistujat:",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "More options …" : "Lisää valintoja…",
    "More options at %s" : "Lisää valintoja kohteessa %s",
    "Contacts" : "Yhteystiedot",
    "{actor} created address book {addressbook}" : "{actor} loi osoitekirjan {addressbook}",
    "You created address book {addressbook}" : "Loit osoitekirjan {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} poisti osoitekirjan {addressbook}",
    "You deleted address book {addressbook}" : "Sinä poistit osoitekirjan {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} päivitti osoitekirjaa {addressbook}",
    "You updated address book {addressbook}" : "Sinä päivitit osoitekirjaa {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} jakoi osoitekirjan {addressbook} kanssasi",
    "You shared address book {addressbook} with {user}" : "Jaoit osoitekirjan {addressbook} käyttäjän {user} kanssa",
    "{actor} shared address book {addressbook} with {user}" : "{actor} jakoi osoitekirjan {addressbook} käyttäjän {user} kanssa",
    "You shared address book {addressbook} with group {group}" : "Jaoit osoitekirjan {addressbook} ryhmän {group} kanssa",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} jakoi osoitekirjan {addressbook} ryhmän {group} kanssa",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} loi yhteystiedon {card} osoitekirjaan {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Loit yhteystiedon {card} osoitekirjaan {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} poisti yhteystiedon {card} osoitekirjasta {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Poistit yhteystiedon {card} osoitekirjasta {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} päivitti yhteystietoa {card} osoitekirjassa {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Päivitit yhteystiedon {card} osoitekirjassa {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>Yhteystietoa</strong> tai <strong>osoitekirjaa</strong> muokattiin",
    "File is not updatable: %1$s" : "Tiedosto ei ole päivitettävissä: %1$s",
    "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
    "Could not open file" : "Tiedoston avaaminen ei onnistunut",
    "File not found: %1$s" : "Tiedostoa ei löydy: %1$s",
    "System is in maintenance mode." : "Järjestelmä on huoltotilassa",
    "Upgrade needed" : "Päivitys tarvitaan",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s tulee asettaa käyttämään HTTPS-yhteyttä, jotta CalDAVia ja CardDAVia voi käyttää iOSilla tai macOS:llä.",
    "Configures a CalDAV account" : "Määrittää CalDAV-tilin",
    "Configures a CardDAV account" : "Määrittää CardDAV-tilin",
    "Events" : "Tapahtumat",
    "Tasks" : "Tehtävät",
    "Untitled task" : "Nimetön tehtävä",
    "Contacts and groups" : "Yhteystiedot ja ryhmät",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV-päätepiste",
    "Availability" : "Saatavuus",
    "Time zone:" : "Aikavyöhyke:",
    "to" : "Vastaanottaja",
    "Delete slot" : "Poista aikarako",
    "No working hours set" : "Työskentelytunteja ei ole asetettu",
    "Add slot" : "Lisää aikarako",
    "Monday" : "Maanantai",
    "Tuesday" : "Tiistai",
    "Wednesday" : "Keskiviikko",
    "Thursday" : "Torstai",
    "Friday" : "Perjantai",
    "Saturday" : "Lauantai",
    "Sunday" : "Sunnuntai",
    "Save" : "Tallenna",
    "Calendar server" : "Kalenteripalvelin",
    "Send invitations to attendees" : "Lähetä kutsut osallistujille",
    "Automatically generate a birthday calendar" : "Luo syntymäpäiväkalenteri automaattisesti",
    "Birthday calendars will be generated by a background job." : "Syntymäpäiväkalenterit luodaan taustatyön toimesta.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Sen vuoksi ne eivät ole välittömästi saatavilla käyttöönoton jälkeen, vaan ne tulevat näkyviin pienellä viiveellä.",
    "Send notifications for events" : "Lähetä ilmoitukset tapahtumista",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Asenna myös {calendarappstoreopen}kalenterisovellus{linkclose}, tai {calendardocopen}yhdistä tietokoneesi ja mobiililaitteesi synkronointiyhteyteen ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Varmista että määrität {emailopen}sähköpostipalvelimen{linkclose} asetukset oikein.",
    "There was an error updating your attendance status." : "Osallistumisesi tilaa päivittäessä tapahtui virhe.",
    "Please contact the organizer directly." : "Ota yhteys suoraan järjestäjään.",
    "Are you accepting the invitation?" : "Hyväksytkö kutsun?",
    "Tentative" : "Alustava",
    "Number of guests" : "Vieraiden määrä",
    "Comment" : "Kommentti",
    "Your attendance was updated successfully." : "Osallistumisesi päivitettiin onnistuneesti."
},
"nplurals=2; plural=(n != 1);");
